@@ -1,6 +1,7 @@
 from typing import Optional
 
 import click
+
 from memfault_cli.authenticator import Authenticator
 
 
@@ -132,6 +133,11 @@ class MemfaultCliClickContext(object):
     def must_pass_through(self):
         return self._find_obj_or_raise("must_pass_through")
 
+    @property
+    def notes(self):
+        # release notes for an OTA package
+        return self._find_obj_or_raise("notes")
+
     @property
     def android_package_info(self) -> Optional[PackageInfo]:
         package = self.obj.get("package")
